@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.29 2004/06/30 08:01:52 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.30 2004/07/04 03:12:42 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -228,6 +228,7 @@ void do_child(int unix_fd, int inet_fd)
 			POOL_STATUS status;
 
 			status = pool_process_query(frontend, backend, 0);
+
 			switch (status)
 			{
 				/* client exits */
@@ -243,9 +244,16 @@ void do_child(int unix_fd, int inet_fd)
 					else
 					{
 						/* send reset request to backend */
-						pool_process_query(frontend, backend, 1);
+						status = pool_process_query(frontend, backend, 1);
 						pool_close(frontend);
-						pool_connection_pool_timer(backend);
+
+						/* if we detect errors on resetting connection, we need to discard
+						 *this connection since it might be in unknown status
+						 */
+						if (status != POOL_CONTINUE)
+							pool_discard_cp(sp->user, sp->database, sp->major);
+						else
+							pool_connection_pool_timer(backend);
 					}
 					break;
 				
@@ -257,6 +265,7 @@ void do_child(int unix_fd, int inet_fd)
 					pool_close(frontend);
 					notice_backend_error();
 #endif
+					pool_log("do_child: exits with status 1 due to error");
 					exit(1);
 					break;
 
