@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.20 2004/06/10 10:25:22 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.21 2004/06/30 08:01:52 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -383,10 +383,20 @@ static POOL_CONNECTION_POOL_SLOT *create_cp(POOL_CONNECTION_POOL_SLOT *cp, int s
 {
 	int fd;
 
-	if (*pool_config.current_backend_host_name == '\0')
-		fd = connect_unix_domain_socket(secondary_backend);
+	if (secondary_backend)
+	{
+		if (*pool_config.secondary_backend_host_name == '\0')
+			fd = connect_unix_domain_socket(1);
+		else
+			fd = connect_inet_domain_socket(1);
+	}
 	else
-		fd = connect_inet_domain_socket(secondary_backend);
+	{
+		if (*pool_config.current_backend_host_name == '\0')
+			fd = connect_unix_domain_socket(0);
+		else
+			fd = connect_inet_domain_socket(0);
+	}
 
 	if (fd < 0)
 	{
